@@ -5,8 +5,6 @@ from gql.transport.aiohttp import AIOHTTPTransport
 
 import json
 import os
-import warnings
-from urllib import request, error as urlib_error
 
 PROPERTIES_KEY = 'properties'
 
@@ -25,7 +23,7 @@ class Client:
 
         self.stage = stage
 
-    async def create_entity(self, entity: dict) -> dict:
+    def create_entity(self, entity: dict) -> dict:
         """
         Create an entity
         :param entity: dict with properties:
@@ -50,14 +48,14 @@ class Client:
             "stage": self.stage
         }
 
-        result = (await self.client.execute_async(query, variable_values=params))
+        result = self.client.execute(query, variable_values=params)
         result = result['createEntity']
 
         result[PROPERTIES_KEY] = json.loads(result[PROPERTIES_KEY])
 
         return result
 
-    async def delete_entity(self, entity):
+    def delete_entity(self, entity):
         query = gql(
             """
             mutation deleteEntity($entity: EntityInput, $stage: String) {
@@ -73,12 +71,12 @@ class Client:
             "stage": self.stage
         }
 
-        result = (await self.client.execute_async(query, variable_values=params))
+        result = self.client.execute(query, variable_values=params)
         result = result['deleteEntity']
 
         return result
 
-    async def batch_create_entities(self, entities: list) -> list:
+    def batch_create_entities(self, entities: list) -> list:
         """
         Create a batch of entities
         """
@@ -98,7 +96,7 @@ class Client:
             "stage": self.stage
         }
 
-        results = (await self.client.execute_async(query, variable_values=params))
+        results = self.client.execute(query, variable_values=params)
         results = results['batchCreateEntities']
 
         for result in results:
@@ -106,7 +104,7 @@ class Client:
 
         return results
 
-    async def create_event(self, in_entity: dict, event: dict | str, out_entity: dict) -> dict:
+    def create_event(self, in_entity: dict, event: dict | str, out_entity: dict) -> dict:
         """
         Create an event
         :param in_entity: entity that is the source of the event
@@ -138,12 +136,12 @@ class Client:
             "stage": self.stage
         }
 
-        result = (await self.client.execute_async(query, variable_values=params))
+        result = self.client.execute(query, variable_values=params)
         result = result['createEvent']
 
         return result
 
-    async def batch_create_events(self, events: list) -> list:
+    def batch_create_events(self, events: list) -> list:
         """
         Create a batch of events and embed them in a batch
         """
@@ -165,12 +163,12 @@ class Client:
             "stage": self.stage
         }
 
-        results = (await self.client.execute_async(query, variable_values=params))
+        results = self.client.execute(query, variable_values=params)
         results = results['batchCreateEvents']
 
         return results
 
-    async def delete_event(self, in_entity: dict, event: dict | str, out_entity: dict) -> dict:
+    def delete_event(self, in_entity: dict, event: dict | str, out_entity: dict) -> dict:
         """
         Delete an event
         :param in_entity: entity that is the source of the event
@@ -202,12 +200,12 @@ class Client:
             "stage": self.stage
         }
 
-        result = (await self.client.execute_async(query, variable_values=params))
+        result = self.client.execute(query, variable_values=params)
         result = result['deleteEvent']
 
         return result
 
-    async def recommend(self, entity, label, limit=10, query=None):
+    def recommend(self, entity, label, limit=10, query=None):
         """
         Find similar entities to the given entity
         :param entity: entity for which similar entities are to be found
@@ -240,7 +238,7 @@ class Client:
             "stage": self.stage
         }
 
-        result = (await self.client.execute_async(gqlquery, variable_values=params))
+        result = self.client.execute(gqlquery, variable_values=params)
         result = result['similar']
 
         return self._parse_response(result)
